﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System.Net.Security;
using System.ServiceModel;
using HeuristicLab.Services.UserManagement.DataTransfer;

namespace HeuristicLab.Services.UserManagement {
  [ServiceContract(ProtectionLevel = ProtectionLevel.EncryptAndSign)]
  public interface IUserManagementService {

    #region User
    [OperationContract]
    IEnumerable<User> GetUsers(Application application);

    [OperationContract]
    User AddUser(User user);

    [OperationContract]
    void DeleteUser(User user);

    [OperationContract]
    void UpdateUser(User user);

    [OperationContract]
    void AddUserToRole(Role role, User user);

    [OperationContract]
    void RemoveUserFromRole(Role role, User user);

    [OperationContract]
    bool IsUserInRole(User user, Role role);

    [OperationContract]
    User ResetPassword(string applicationName, string userName, string password);
    #endregion

    #region Role
    [OperationContract]
    IEnumerable<Role> GetRoles(Application application);

    [OperationContract]
    Role AddRole(Role role);

    [OperationContract]
    void UpdateRole(Role role);

    [OperationContract]
    void DeleteRole(Role role);

    [OperationContract]
    IEnumerable<Role> GetUserRoles(User user);
    #endregion

    #region Application
    [OperationContract]
    IEnumerable<Application> GetApplications();

    [OperationContract]
    IEnumerable<User> GetApplicationUsers(Application application);

    [OperationContract]
    Application AddApplication(Application application);

    [OperationContract]
    void UpdateApplication(Application application);

    [OperationContract]
    void DeleteApplication(Application application);
    #endregion

    #region Client specific methods
    [OperationContract]
    bool CheckUserExists(string application, string userName, string password);

    [OperationContract]
    bool GetUser(string application, string userName, string password);
    #endregion
  }
}
